********************************************************************************
*This file is used for the counterfactual analyses under the assumption of Cournot bank competition in deposit market.




global workdir 		= "B:\CBDC-Li"
global data 		= "$workdir\data"
global code         = "B:\CBDC-Li\code\JME revision"

clear all
set maxvar 120000


global date         = "15Jun22"


********************************************************************************
*Keep the variables that will be used in counterfactual analysis 
********************************************************************************
clear
use "$data/Data_varlabel_edited_v4_MOP13.dta"

gen anonymI = -(anonym - 1)
gen budgetI = -(budget - 1)
gen cons = 1

rename regioncat5   regioncat
rename ageheadcat5  ageheadcat
rename att_risk1    risk
rename att_debt1    debt

//estimate demand parameters  
global  attributelist  rate  bundling  reldif_costopp_dc  reldif_ease_dc reldif_secur_dc anonymI budgetI sn_loc_online_mop frac_card_unaccep
global demolist1   risk   debt  ind_behinddebt  ind_rent  ind_inetwork   female  ind_rural   ind_TD ind_RBC ind_LAU  ind_OT 
global demolist2   ageheadcat  ind_hldincome  hldsizecat  educhead  year  regioncat 
global demolist2i   i.ageheadcat  i.ind_hldincome  i.hldsizecat  i.educhead   i.year  i.regioncat 
qui  reg  log_dep3_cash  ${attributelist}  ${demolist1}  ${demolist2i}  if inrange(year, 2010, 2017),  vce(robust)
gen sample = 1 if e(sample)


//save fitted value 
cap drop sample
cap drop xb
qui gen sample = 1 if e(sample)
predict xb if sample == 1 , xb


global b_rate = _b[rate]
//generate utility difference excluding the rate of return: xb_excl_rd
gen xb_excl_rd = xb - ${b_rate}*rate


//generate wealth weight 
qui gen wealth = cash + tot_dep3 if sample == 1       
winsor wealth, gen(wealth_w) p(0.01) highonly
bys year: egen tot_wealth_w = sum(wealth_w)          
qui gen wealth_frac = wealth_w/tot_wealth_w          

//generate predicted cash and deposit shares before introducing CBDC
qui gen s_cash_old = 1/(1 + exp(xb)) if sample == 1                       
qui gen s_dep_old = 1 - s_cash_old if sample == 1							
	
		
*-------------------------------------------------------------------------------
*Construct bank marginal cost 
*-------------------------------------------------------------------------------

//average pre-tax deposit rates across households = pre-tax weighted average deposit rates across banks
gen rate_pretax = rate/(1 - margtax_hldincome)
bys year: egen mean_rd = mean(rate_pretax) if sample == 1

su mean_rd if year == 2017
/*
   Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
     mean_rd |        481    .0785738           0   .0785738   .0785738
*/

  
//generate predicted cash and deposit shares before introducing CBDC
qui gen s_cash = 1/(1 + exp(xb_excl_rd + ${b_rate}*mean_rd*(1 - margtax_hldincome))) if sample == 1        
qui gen s_dep = 1 - s_cash if sample == 1	
gen q_d = s_dep*wealth_w 
gen q_c = s_cash*wealth_w


bys year: egen aggr_dep = sum(q_d)
gen ws_cash = q_d/aggr_dep*s_cash*(1 - margtax_hldincome)

bys year: egen aws_cash = sum(ws_cash)
gen semi_elas = ${b_rate}*aws_cash
gen inv_semi_elas = semi_elas^(-1)

//marginal cost 
//5-year closed mortgage rate is around 4.79% across the big six banks in 2017 -weighted average
gen mean_rl = 4.78

//change the number of banks here and recalculate the marginal cost
//when N = 11, the profit margin matches the net interest income over total assets ratio of 1.47%

//CHANGE THE NUMBER OF BANKS HERE
global nbanks   = 6                /*number of banks is calibrated*/

gen mkup_n${nbanks} = inv_semi_elas/ ${nbanks}
gen mc_n${nbanks} = mean_rl - mean_rd - mkup_n${nbanks}
	
	
//keep selected variables to reduce data size 
keep id hldid year   mean_rl  mean_rd   mc_n*  xb_excl_rd  mkup_n*   log_dep3_cash  ${attributelist}  ${demolist1}  ${demolist2}  cons  sample wealth wealth_w wealth_frac  s_dep  s_cash  s_cash_old s_dep_old  xb  costopp_*  ease_*  secur_*  sum_*   margtax_hldincome

save "$data//Bank responses//Data_varlabel_edited_v4_MOP13_selectedvars_for_CF_nbanks${nbanks}_mean_pretax_rate.dta", replace



********************************************************************************
*Run different specifications in parallel
********************************************************************************

//run program predictionv3 
do "$code\Endogenous bank responses\program_prediction_v3"		


//Set the number of cores to be used 
global nclusters = 12
parallel initialize $nclusters


local rho_list      0   
local gamma_list    0   0.1   0.2   0.3    0.4    0.5   0.6   0.7   0.8   0.9   1
local eta_list      0   0.1   0.2   0.3    0.4    0.5   0.6   0.7   0.8   0.9   1



local joblist = ""
foreach model in nest_d_cbdc    {
	
	foreach design in  design_real  design_d  design_c   {
		if "`design'" == "design_d" {
			local charlist d 
		}
		else if "`design'" == "design_c" {
			local charlist c
		}
		else if "`design'" == "design_real" {
			local charlist real 
		}
		//CHANGE HERE!
		//If only study the cbdc demand under basic designs -> local charlist `charlist' 

		local featurelist  rate   budget     anonym    bundling  
		local charlist `charlist'  `featurelist'
		
		foreach charname of local charlist {
			foreach rho of local rho_list {
				foreach gamma of local gamma_list  {
					//if not studying attribute change
					if  "`featurelist'" == "" {
						foreach eta of local eta_list {
							local joblist `joblist' `model'XXX`design'XXX`charname'XXX`rho'XXX`gamma'XXX`eta'
						}
					}
					//when studying the attributes, can set eta and gamma the same
					if  "`featurelist'" != "" {
						local eta  `gamma'       
						local joblist `joblist' `model'XXX`design'XXX`charname'XXX`rho'XXX`gamma'XXX`eta'
					}
				}
			}
		}	
	}
}
di "`joblist'"


//Note that parfor.ado is written separately
parallel, prog(predictionv3) nodata: parfor, nclusters($nclusters)  program("predictionv3") joblist("`joblist'")                              
















