********************************************************************************
*This program generates the inverse semi-elasticity and the residual from the symmetric bank's FOC
*Created on 20 April, 2022



cap program drop bank_foc
program  bank_foc, rclass
	syntax [, dep_rate(string)  model(string)]
	
	tempvar log_dep_cash   
	//xb = index for log_dep_cash excluding the rate of return, already in the data
    qui gen `log_dep_cash' = xb_excl_rd + ${b_rate} * `dep_rate' * (1 - margtax_hldincome)
	
	tempvar dif_Vcbdc_Vd  factor s_dep s_cbdc s_cash  q_dep  D
	//note that when banks respond, Vd will also change
	if "`model'" == "nest_d_cbdc" {
		local tau_d = $tau
		qui gen double `dif_Vcbdc_Vd' = dif_Vcbdc_Vd_rd_${iter} - ${b_rate} * `dep_rate' * (1 - margtax_hldincome)
		qui gen double `factor' = (1 + exp(`dif_Vcbdc_Vd'/`tau_d'))^(1 - `tau_d')
		qui gen double `s_dep' = 1/(1 + `factor'*exp(-`log_dep_cash') + exp(`dif_Vcbdc_Vd'/`tau_d'))
		qui gen double `s_cbdc' = exp(`dif_Vcbdc_Vd'/`tau_d')*`s_dep'
		qui gen double `s_cash' = 1 - `s_dep' - `s_cbdc'
	}
	if "`model'" == "nest_c_cbdc" {
		local tau_c = $tau
		//note that dif_Vcbdc_Vc will not change with the deposit rate
		qui gen double `factor' = (1 + exp(dif_Vcbdc_Vc_${iter}/`tau_c'))^(1 - `tau_c')
		qui gen double `s_cash' = 1/(1 + `factor'*exp(`log_dep_cash') + exp(dif_Vcbdc_Vc_${iter} /`tau_c'))
		qui gen double `s_cbdc' = exp(dif_Vcbdc_Vc_${iter} /`tau_c')*`s_cash'
		qui gen double `s_dep' = 1 - `s_cash' - `s_cbdc'
	}
	
	//predicted deposit balance q at each bank i
    qui gen `q_dep' = `s_dep'*wealth_w
	//expected aggregate deposit at each bank
	qui bys year: egen `D' = sum(`q_dep')
 
	tempvar  ws_share  sum_ws_share  inv_semi_elas foc  mkup

	qui gen `ws_share' = `q_dep'/`D'*(1 - `s_dep') * (1 - margtax_hldincome)
	qui bys year: egen `sum_ws_share' = sum(`ws_share')
	qui gen `inv_semi_elas' = ( ${b_rate} *`sum_ws_share')^(-1)
	//note that marginal cost is calculated under mean_rd in the data and a specific number of banks
	qui gen `foc' = mean_rl - mc_n${nbanks} - `dep_rate' - `inv_semi_elas'/ ${nbanks}
	qui gen `mkup' = `inv_semi_elas'/ ${nbanks}
	
	qui su year
	forval yr = `r(min)'(1)`r(max)' {
		qui su `foc' if year == `yr' 
		return scalar foc`yr' = r(mean)
		qui su `mkup' if year == `yr' 
		return scalar mkup`yr' = r(mean)
		
	} 
	
end	


